django_analyses.models.input.definitions package — django_analyses 0.0.3 documentation

# django_analyses.models.input.definitions package

## Submodules

## django_analyses.models.input.definitions.boolean_input_definition module

class `django_analyses.models.input.definitions.boolean_input_definition.` `BooleanInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr, default, is_output_switch)

  Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.MultipleObjectsReturned`

  `default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.boolean_input.BooleanInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `inputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `inputdefinition_ptr_id`
  `is_output_switch`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.definitions.directory_input_definition module

class `django_analyses.models.input.definitions.directory_input_definition.` `DirectoryInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr, is_output_directory, default)

  Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.MultipleObjectsReturned`

  `default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.directory_input.DirectoryInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `inputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `inputdefinition_ptr_id`
  `is_output_directory`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.definitions.file_input_definition module

class `django_analyses.models.input.definitions.file_input_definition.` `FileInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr)

  Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.MultipleObjectsReturned`

  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.file_input.FileInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `inputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `inputdefinition_ptr_id`

## django_analyses.models.input.definitions.float_input_definition module

class `django_analyses.models.input.definitions.float_input_definition.` `FloatInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr, numberinputdefinition_ptr, min_value, max_value, default)

  Bases: `django_analyses.models.input.definitions.number_input_definition.NumberInputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.number_input_definition.NumberInputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.number_input_definition.NumberInputDefinition.MultipleObjectsReturned`

  `default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.float_input.FloatInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `max_value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `min_value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `numberinputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `numberinputdefinition_ptr_id`

## django_analyses.models.input.definitions.input_definition module

class `django_analyses.models.input.definitions.input_definition.` `InputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input)

  Bases: `django.db.models.base.Model`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `booleaninputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `check_input_class_definition`() → None
  `default` = None
  `description`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `directoryinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `fileinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `get_or_create_input_instance`(**kwargs) → django_analyses.models.input.input.Input
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `input_class` = None
  `is_configuration`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `key`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `listinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `numberinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `objects` = <django_analyses.models.managers.input_definition.InputDefinitionManager object>
  `pipe_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `required`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `run_method_input`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `save`(*args, **kwargs)

    Save the current instance. Override this in a subclass if you want to control the saving process.

    The ‘force_insert’ and ‘force_update’ parameters can be used to insist that the “save” must be an SQL insert or update (or equivalent for non-SQL backends), respectively. Normally, they should not be set.

  `specification_set`

    Accessor to the related objects manager on the forward and reverse sides of a many-to-many relation.

    In the example:

        class Pizza(Model):
            toppings = ManyToManyField(Topping, related_name='pizzas')

    `Pizza.toppings` and `Topping.pizzas` are `ManyToManyDescriptor` instances.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `stringinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `validate`() → None
  `value_attribute`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

## django_analyses.models.input.definitions.input_definitions module

class `django_analyses.models.input.definitions.input_definitions.` `InputDefinitions`

  Bases: `enum.Enum`

  An enumeration.

  `BLN` = 'Boolean'
  `DIR` = 'Directory'
  `FIL` = 'File'
  `FLT` = 'Float'
  `INT` = 'Integer'
  `LST` = 'List'
  `STR` = 'String'

## django_analyses.models.input.definitions.integer_input_definition module

class `django_analyses.models.input.definitions.integer_input_definition.` `IntegerInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr, numberinputdefinition_ptr, min_value, max_value, default)

  Bases: `django_analyses.models.input.definitions.number_input_definition.NumberInputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.number_input_definition.NumberInputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.number_input_definition.NumberInputDefinition.MultipleObjectsReturned`

  `default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.integer_input.IntegerInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `max_value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `min_value`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `numberinputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `numberinputdefinition_ptr_id`

## django_analyses.models.input.definitions.list_input_definition module

class `django_analyses.models.input.definitions.list_input_definition.` `ListInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr, element_type, min_length, max_length, default)

  Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.MultipleObjectsReturned`

  `default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `element_type`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_element_type_display`(*, field=<django.db.models.fields.CharField: element_type>)
  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.list_input.ListInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `inputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `inputdefinition_ptr_id`
  `max_length`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `min_length`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `raise_max_length_error`() → None
  `raise_min_length_error`() → None
  `raise_not_list_error`() → None
  `raise_wrong_type_error`() → None
  `validate`()
  `validate_default_value`() → None
  `validate_default_value_max_length`() → bool
  `validate_default_value_min_length`() → bool
  `validate_elements_type_for_default`() → bool

## django_analyses.models.input.definitions.messages module

## django_analyses.models.input.definitions.number_input_definition module

class `django_analyses.models.input.definitions.number_input_definition.` `NumberInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr)

  Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.MultipleObjectsReturned`

  `floatinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `inputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `inputdefinition_ptr_id`
  `integerinputdefinition`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `raise_default_over_max_error`()
  `raise_default_under_min_error`()
  `validate`() → None
  `validate_default`()

## django_analyses.models.input.definitions.string_input_definition module

class `django_analyses.models.input.definitions.string_input_definition.` `StringInputDefinition`(id, key, required, description, is_configuration, value_attribute, run_method_input, inputdefinition_ptr, min_length, max_length, default, dynamic_default, choices, is_output_path, is_output_switch)

  Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition`

  exception `DoesNotExist`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.DoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django_analyses.models.input.definitions.input_definition.InputDefinition.MultipleObjectsReturned`

  `choices`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `dynamic_default`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_type`() → django_analyses.models.input.definitions.input_definitions.InputDefinitions
  `input_class`

    alias of `django_analyses.models.input.types.string_input.StringInput`

  `input_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `inputdefinition_ptr`

    Accessor to the related object on the forward side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Restaurant.place` is a `ForwardOneToOneDescriptor` instance.

  `inputdefinition_ptr_id`
  `is_output_path`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `is_output_switch`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `max_length`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `min_length`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `raise_default_not_in_choices_error`() → None
  `validate`() → None

## Module contents